@@ -5,7 +5,7 @@ import hashlib
 import ssl
 from pathlib import Path
 from shutil import unpack_archive
-from typing import Callable, Iterable, Union
+from typing import Callable, Iterable, Optional, Union
 from urllib import request
 
 import matplotlib.pyplot as plt  # type: ignore
@@ -43,7 +43,7 @@ def download_file(url: str, path: Path, print_progress: bool) -> None:
     request.urlretrieve(url, path, reporthook=fn_callback)
 
 
-def check_integrity(path: Path, md5_hash: str = str(None)) -> bool:
+def check_integrity(path: Path, md5_hash: Optional[str] = None) -> bool:
     """Check the integrity of a file.
 
     The integrity of the file is ensured by checking if the path points to a file. Eventually,
@@ -51,7 +51,7 @@ def check_integrity(path: Path, md5_hash: str = str(None)) -> bool:
 
     Args:
         path: the path to the file.
-        md5_hash: the Defaults to None.
+        md5_hash: the md5_hash has to check. the Defaults to None.
 
     Returns:
         True if the check is passed.
@@ -88,7 +88,7 @@ def download_and_extract(
     url: str,
     path_file_downloaded: Path,
     path_destination: Path,
-    md5_hash: str = str(None),
+    md5_hash: Optional[str] = None,
 ) -> None:
     """Download a compressed file from the url and extract it into path_destination.
 
